scxpand.pretrained
==================

.. automodule:: scxpand.pretrained

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   download_manager
   inference_api
   model_registry
